summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRob Staudinger <robsta@linux.intel.com>2012-01-24 10:33:53 +0100
committerRob Staudinger <robsta@linux.intel.com>2012-01-24 10:33:53 +0100
commit45a01f95eecaaee49ab94ccdc3211d3c917f056e (patch)
tree78c621a5728f823291f7326035d8306427914e9c
parent333117d1fec9778595177369522d08e1e5a18a8a (diff)
Client: move away from deprecated API
Phase out the use of deprecated tp_account_prepare_*() calls, move to tp_account_prepare_*() instead.
-rw-r--r--ytstenut/yts-client.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/ytstenut/yts-client.c b/ytstenut/yts-client.c
index 641697d..c9f46cd 100644
--- a/ytstenut/yts-client.c
+++ b/ytstenut/yts-client.c
@@ -1171,7 +1171,7 @@ setup_tp_client (YtsClient *self,
}
/*
* Callback from the async tp_account_prepare_async() call
*
* This function is ready for the New World Order according to Ytstenut ...
*/
@@ -1183,7 +1183,7 @@ yts_client_account_prepared_cb (GObject *source_object,
TpAccount *account = TP_ACCOUNT (source_object);
GError *error = NULL;
- if (!tp_account_prepare_finish (account, res, &error)) {
+ if (!tp_proxy_prepare_finish (account, res, &error)) {
g_critical ("Account unprepared: %s", error->message);
g_clear_error (&error);
return;
@@ -1217,10 +1217,10 @@ yts_client_account_cb (GObject *source_object,
g_message ("Got account");
- tp_account_prepare_async (account,
- &features[0],
- yts_client_account_prepared_cb,
- self);
+ tp_proxy_prepare_async (account,
+ features,
+ yts_client_account_prepared_cb,
+ self);
}
static void
@@ -1171,7 +1171,7 @@ setup_tp_client (YtsClient *self,
}
/*
- * Callback from the async tp_account_prepare_async() call
+ * Callback from the async tp_proxy_prepare_async() call
*
* This function is ready for the New World Order according to Ytstenut ...